@@ -1,16 +1,16 @@
 from django.views.generic import TemplateView, FormView
-from .forms import preference_form_builder, user_preference_form_builder
-from .registries import user_preferences_registry, global_preferences_registry
-from .models import user_preferences, global_preferences
+from .forms import preference_form_builder
+
 
 """Todo : remove these views and use only context processors"""
 class RegularTemplateView(TemplateView):
     """Used for testing context"""
-    template_name = "dynamic_preferences/testcontext.html" 
+    template_name = "dynamic_preferences/testcontext.html"
+
 
 class PreferenceFormView(FormView):
     """Display a form for updating preferences of the given section provided via URL arg.
-    If no section is provided, will dispaly a form for all fields of a given registry.
+    If no section is provided, will display a form for all fields of a given registry.
     """
 
     #: the registry for preference lookups
@@ -38,17 +38,6 @@ class PreferenceFormView(FormView):
         return self.request.path
 
     def form_valid(self, form):
-        
+
         form.update_preferences()
         return super(PreferenceFormView, self).form_valid(form)
-
-class UserPreferenceFormView(PreferenceFormView):
-    """
-    Will pass `request.user` to form_builder
-    """
-    registry = user_preferences_registry
-    
-    def get_form_class(self, *args, **kwargs):
-        section = self.kwargs.get('section', None)
-        form_class = user_preference_form_builder(user=self.request.user, section=section)
-        return form_class
\ No newline at end of file
